export interface PendingItem {
    path: string;
    distPath: string;
    originSize: number;
}
interface UploadRes {
    input: {
        size: number;
        type: string;
    };
    output: {
        size: number;
        type: string;
        width: number;
        height: number;
        ratio: number;
        url: string;
    };
}
declare class TinyPng {
    private pendingList;
    private successList;
    private failedList;
    private asyncTaskQueue;
    constructor(maxTasks?: number);
    setPendingList(list: any): void;
    run(): Promise<unknown>;
    /**
     * compress a image file and save it
     * @param sourcePath source image file path
     * @param distpath compressed image file dist path
     * @returns distpath
     */
    compressSinglePic(sourcePath: string, distpath: string): Promise<UploadRes>;
    /**
     * upload a image
     * @param path source image path
     * @returns promise with upload result
     */
    uploadSinglePic(path: string): Promise<UploadRes>;
    /**
     * download image from tiny.png
     * @param address image url to download
     * @param distPath the path image to be saved
     * @returns distPath
     */
    downloadSingleImg(address: any, distPath: string): void;
    printStart(): void;
    /**
     * print the result, include originTotalSize, compressedTotalSize, compressRatio
     */
    printResult(): void;
    printFailed(): void;
}
export default TinyPng;
