#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const fs_extra_1 = require("fs-extra");
const TinyPng_1 = require("./TinyPng");
const utils_1 = require("./utils");
const packageJson = require('../package.json');
(function main() {
    const program = new commander_1.Command();
    program
        .version(packageJson.version, '-v, --version', 'how current version')
        .arguments('<file>')
        .option('-o, --output <output>', 'set output path')
        .option('-a, --all', 'force compress all images(include compressed images)')
        .option('-m, --max [max]', 'max async compress tasks')
        .description('A cli tool to compress image', {
        file: 'input file path',
    })
        .action((file, options) => {
        const { output = file, max = 10, all } = options;
        const originPath = utils_1.getFullPath(file);
        fs_extra_1.stat(originPath)
            .then(async (stats) => {
            let pendingList;
            if (stats.isDirectory()) {
                pendingList = (await utils_1.findAllImageFile(originPath)).map((item) => ({
                    ...item,
                    distPath: item.path.replace(originPath, utils_1.getFullPath(output)),
                }));
            }
            if (stats.isFile()) {
                pendingList = [
                    {
                        path: originPath,
                        originSize: stats.size,
                        distPath: utils_1.getFullPath(output),
                    },
                ];
            }
            if (!all) {
                // filter the compressed images
                pendingList = (await Promise.all(pendingList.map(async (item) => {
                    const isCompressed = await utils_1.judgeImageIsCompressed(item.path);
                    return isCompressed ? null : item;
                }))).filter(Boolean);
            }
            const tinyPng = new TinyPng_1.default(max);
            tinyPng.setPendingList(pendingList);
            tinyPng.run();
        })
            .catch((err) => {
            console.log(err);
        });
    });
    program.parse();
})();
